@@ -4,8 +4,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.06';
-our $impl = 'unloaded';
+our $VERSION = '0.07';
 our @EXPORT = qw(
   pkgconf_cflags
   pkgconf_libs
@@ -15,8 +14,6 @@ our @EXPORT = qw(
   pkgconf_libs_static
 );
 
-require PkgConfig::LibPkgConf::XS;
-
 =head1 NAME
 
 PkgConfig::LibPkgConf - Interface to .pc file interface via libpkgconf
@@ -215,6 +212,8 @@ Contributors:
 
 A. Wilcox (awilfox)
 
+Petr Pisar (ppisar)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 Graham Ollis.
