@@ -3,12 +3,9 @@ package PkgConfig::LibPkgConf::XS;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 require XSLoader;
 XSLoader::load('PkgConfig::LibPkgConf', $VERSION);
 
-$PkgConfig::LibPkgConf::impl = 
-$PkgConfig::LibPkgConf::impl = 'XS';
-
 1;
